rate

package
v0.0.0-...-a649600 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 6, 2021 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package rate is a generated protocol buffer package.

It is generated from these files:

github.com/ship-os/ship-micro/examples/booking/srv/rate/proto/rate.proto

It has these top-level messages:

Request
Result
RatePlan
RoomType

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RegisterRateHandler

func RegisterRateHandler(s server.Server, hdlr RateHandler, opts ...server.HandlerOption)

Types

type RateHandler

type RateHandler interface {
	// GetRates returns rate codes for hotels for a given date range
	GetRates(context.Context, *Request, *Result) error
}

type RateService

type RateService interface {
	// GetRates returns rate codes for hotels for a given date range
	GetRates(ctx context.Context, in *Request, opts ...client.CallOption) (*Result, error)
}

func NewRateService

func NewRateService(serviceName string, c client.Client) RateService

Jump to